package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````=!<``#0```"``0$```(`!30`(``)
M`"@`&P`:``$``'`0BP``$(L``!"+```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$````````````````````<BP``'(L```4```````$`
M`0```+S]``"\_0$`O/T!`(0"``"8`@``!@```````0`"````Q/T``,3]`0#$
M_0$`"`$```@!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DO/T`
M`+S]`0"\_0$`1`(``$0"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5`-U?O!Z2A*/2+E-VN,WX@*CG@L,'!````!`````!
M````1TY5```````#`````@`````````1````3`````@````(`````9`0!"5`
M!(`H@``%H(90A(`!```+*`2,.(`208H```A,````30```%````!4````50``
M`%T```!>````7P````````!A````8@```&,```!D````90```&@`````````
M``````&O-.ANQ=\?SMY'+6M_FGPNQ9NV=E0\E"#_Y`[59-1\V7%8'.)'Q@%"
M^M>'K$OCP+KCDGQ8[Y=YPN4_+/JA;&"S`8MO:PE#UF>OS&9"1=7LB0=PTS-B
MV^T5C"7,#3J7"W^IG)N^VE<;X*<""FL:GE"CX/M)````````````````````
M``````"X$0````````,`"P`````````"```````#`!8`-0(`````````````
M$@```-,!`````````````!(```#S`0`````````````2````E0$`````````
M````(@```.<"`````````````!$```!N`P`````````````2`````0``````
M````````(````*0!`````````````!(````>`@`````````````2````MP$`
M````````````$@```/@``````````````!(```"_`0`````````````2````
M`P,`````````````$0```(,"`````````````!(```!<`0`````````````2
M````D@(`````````````$@```#P"`````````````!(```!T````````````
M```2````\P``````````````$@```$\"`````````````!(```#)`@``````
M```````2````\0(`````````````$@```),"`````````````!(````!`@``
M```````````2````5@(`````````````$@```-$``````````````!$```!.
M`0`````````````2````LP``````````````$0```!P!`````````````!(`
M``#``@`````````````2````?`(`````````````$0```(H!````````````
M`!(```"B`@`````````````2````=P$`````````````$@```)H"````````
M`````!(```#Z`0`````````````2````@P$`````````````$@```"H!````
M`````````!(````=```````````````@````L`$`````````````$@```+L"
M`````````````!(```!(`@`````````````2````5```````````````$@``
M`*D!`````````````!(```"#```````````````2````J@(`````````````
M$@```&X"`````````````!(```"/```````````````2````0P$`````````
M````$@```.$"`````````````!(````/`@`````````````2````"0$`````
M````````$@```$8``````````````!(```#]```````````````2````;`$`
M````````````$@```.4!`````````````!(```#````````````````2````
M)0(`````````````$@```-H"`````````````!(```#<```````````````2
M````"`(`````````````$@```&,``````````````!(```"*`@``````````
M```2````Z`(`````````````(0```%X"`````````````!(```"D````````
M```````2````.@$`````````````$@```"P``````````````"````#I`@``
M```````````1````%@(`````````````$@```&@"`````````````!(```!"
M`@`````````````2````+`(`````````````$@```(L#``!4``(``````!``
M%P!W`P``O#<``&`!```2``T`KP,``.PL```,"```$@`-`.`!``"X%```O`(`
M`!(`#0`]`P``."$```0````2``T`3@,``$```@``````$``7`#L$```\(0``
M@`(``!(`#0!Q!```^#0``,0"```2``T`)P0``$```@``````$``7`)8#``"\
M(P``)````!(`#0"\`P``,$8``!@!```2``T`U`,``,!(```$````$0`/``,$
M``!4``(``````!``%P`(!```5``"```````0`!<`,P0``-P?``!<````$@`-
M`$@$``"$*P``:`$``!(`#0!:!```L"H``+P````2``T`QP,``````@``````
M$``6`*,#``#@(P``F`$``!(`#0"#`P``0``"```````0`!8`^0,``#P``@`$
M````$0`6`,T#``!T%P```````!(`#0!H!```I$4``(P````2``T`R0,`````
M`@``````(``6`%P#``!L*P``&````!(`#0"*`P``5``"```````0`!<`XP,`
M`#@@`````0``$@`-`!T$``!(1P``7`$``!(`#0`0!```>"4``#@%```2``T`
M`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?7V=M;VY?<W1A<G1?7P!?
M251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S
M>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L
M7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7W-V7W-E='!V;@!0
M3%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!03%]T:')?:V5Y`%!E<FQ?
M8W)O86M?;65M;W)Y7W=R87``<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?
M871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P
M97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A
M9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`
M7U]C>&%?9FEN86QI>F4`<F5A9`!S=')C:'(`9V5T<&ED`&UE;6UO=F4`<'1H
M<F5A9%]G971S<&5C:69I8P!?7VQI8F-?<W1A<G1?;6%I;@!?7V9P<FEN=&9?
M8VAK`'-T<F-M<`!O<&5N-C0`=6YL:6YK`'-T<G1O:P!M96US970`<W1R;F-M
M<`!G971U:60`;65M8VAR`&-L;W-E9&ER`'-T<G-T<@!R;61I<@!C;&]S90!S
M=')L96X`<W1R9'5P`')E86QL;V,`<F5A9&1I<C8T`&%B;W)T`%]?<W!R:6YT
M9E]C:&L`<W1D97)R`&UE;6-P>0!S=')R8VAR`&QS=&%T-C0`;W!E;F1I<@!L
M<V5E:S8T`%]?97)R;F]?;&]C871I;VX`97AI=`!R96%D;&EN:P!?7W-T86-K
M7V-H:U]F86EL`&%C8V5S<P!M:V1I<@!?7V5N=FER;VX`7U]R96=I<W1E<E]A
M=&9O<FL`7U]S=&%C:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU+C,T`&QI8F,N
M<V\N-@!L9"UL:6YU>"YS;RXS`'!A<E]C=7)R96YT7V5X96,`7U]B<W-?<W1A
M<G1?7P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?
M961A=&$`7U]B<W-?96YD7U\`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A
M<E]M:W1M<&1I<@!S:&%?=7!D871E`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?
M=7-E9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`;7E?<&%R7W!L`%]E;F0`7U]E
M;F1?7P!P87)?:6YI=%]E;G8`<VAA7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN
M:70`<&%R7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE
M86X`<VAA7VEN:70`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N-`!'
M3$E"0U\R+C,S`$=,24)#7S(N,S0```````````(``P`"``(``@`"``$``@`"
M``(``@`#``0``@`!``4``@`!``$``@`"``(`!0`"``(``0`!``$``0`"``(`
M`0`"``$``@`"``(``0`!``(``@`"``$``@`!``(``@`!``$``@`"``$``0`!
M``$``@`!``(``@`!``(``0`"``(``@`!``$``0`"``(``@`"``(``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!`````0`!`"\#```0````(````!1I:0T```0`AP0````````!``,`
M)0,``!``````````LY&6!@``!0"1!```$````+21E@8```,`G`0``!`````4
M:6D-```"`(<$````````O/T!`!<```#`_0$`%P```/#_`0`7````!``"`!<`
M```,``(`%P```!```@`7````&``"`!<````<``(`%P```"```@`7````)``"
M`!<````H``(`%P```#```@`7````-``"`!<````\``(`%P```,S_`0`5!@``
MT/\!`!4)``#4_P$`%0\``-C_`0`5$0``W/\!`!4<``#@_P$`%1X``.3_`0`5
M(0``Z/\!`!4I``#L_P$`%38``/3_`0`50```^/\!`!5&``#\_P$`%4<``-C^
M`0`6`P``W/X!`!8$``#@_@$`%@4``.3^`0`6!@``Z/X!`!8(``#L_@$`%@H`
M`/#^`0`6"P``]/X!`!8,``#X_@$`%@T``/S^`0`6#@```/\!`!80```$_P$`
M%A(```C_`0`6$P``#/\!`!84```0_P$`%A4``!3_`0`6%@``&/\!`!87```<
M_P$`%A@``"#_`0`6&0``)/\!`!8:```H_P$`%AL``"S_`0`6'0``,/\!`!8?
M```T_P$`%B```#C_`0`6(@``//\!`!8C``!`_P$`%B0``$3_`0`6)0``2/\!
M`!8F``!,_P$`%B<``%#_`0`6*```5/\!`!8I``!8_P$`%BH``%S_`0`6*P``
M8/\!`!8L``!D_P$`%BT``&C_`0`6+@``;/\!`!8O``!P_P$`%C```'3_`0`6
M,0``>/\!`!8R``!\_P$`%C,``(#_`0`6-```A/\!`!8U``"(_P$`%C<``(S_
M`0`6.```D/\!`!8Y``"4_P$`%CH``)C_`0`6.P``G/\!`!8\``"@_P$`%CT`
M`*3_`0`6/@``J/\!`!8_``"L_P$`%D$``+#_`0`60P``M/\!`!9$``"X_P$`
M%D4``+S_`0`62```P/\!`!9)``#$_P$`%DH``,C_`0`62P``"$`MZ7T!`.L(
M@+WH!.`MY03@G^4.X(_@"/"^Y?CL`0``QH_B'LJ,XOC\O.4`QH_B'LJ,XO#\
MO.4`QH_B'LJ,XNC\O.4`QH_B'LJ,XN#\O.4`QH_B'LJ,XMC\O.4`QH_B'LJ,
MXM#\O.4`QH_B'LJ,XLC\O.4`QH_B'LJ,XL#\O.4`QH_B'LJ,XKC\O.4`QH_B
M'LJ,XK#\O.4`QH_B'LJ,XJC\O.4`QH_B'LJ,XJ#\O.4`QH_B'LJ,XIC\O.4`
MQH_B'LJ,XI#\O.4`QH_B'LJ,XHC\O.4`QH_B'LJ,XH#\O.4`QH_B'LJ,XGC\
MO.4`QH_B'LJ,XG#\O.4`QH_B'LJ,XFC\O.4`QH_B'LJ,XF#\O.4`QH_B'LJ,
MXEC\O.4`QH_B'LJ,XE#\O.4`QH_B'LJ,XDC\O.4`QH_B'LJ,XD#\O.4`QH_B
M'LJ,XCC\O.4`QH_B'LJ,XC#\O.4`QH_B'LJ,XBC\O.4`QH_B'LJ,XB#\O.4`
MQH_B'LJ,XAC\O.4`QH_B'LJ,XA#\O.4`QH_B'LJ,X@C\O.4`QH_B'LJ,X@#\
MO.4`QH_B'LJ,XOC[O.4`QH_B'LJ,XO#[O.4`QH_B'LJ,XNC[O.4`QH_B'LJ,
MXN#[O.4`QH_B'LJ,XMC[O.4`QH_B'LJ,XM#[O.4`QH_B'LJ,XLC[O.4`QH_B
M'LJ,XL#[O.4`QH_B'LJ,XKC[O.4`QH_B'LJ,XK#[O.4`QH_B'LJ,XJC[O.4`
MQH_B'LJ,XJ#[O.4`QH_B'LJ,XIC[O.4`QH_B'LJ,XI#[O.4`QH_B'LJ,XHC[
MO.4`QH_B'LJ,XH#[O.4`QH_B'LJ,XGC[O.4`QH_B'LJ,XG#[O.4`QH_B'LJ,
MXFC[O.4`QH_B'LJ,XF#[O.4`QH_B'LJ,XEC[O.4`QH_B'LJ,XE#[O.4`QH_B
M'LJ,XDC[O.4`QH_B'LJ,XD#[O.4`QH_B'LJ,XCC[O.4`QH_B'LJ,XC#[O.4`
MQH_B'LJ,XBC[O.4`QH_B'LJ,XB#[O.4`QH_B'LJ,XAC[O.4`````:,*?Y6@R
MG^5P0"WI#,"/X"C03>(<`(WE&!"-Y10@C>4#,)SG'`"-XA@0C>(4((WB0$*?
MY0`PD^4D,(WE`#"@XY___^LP(I_E!$"/X"PRG^4"()3G#""-Y0,PE.<"$*#A
M`P"@X1`PC>7?#`#K$#*?Y0,PE.<`4-/E``!5XU<```H`,I_E`T"4YP``E.4^
M___KQB/0Y0`PH.$"((+CQB/#Y0``E.4X___K'$"=Y00@A.('`7+C`T"$XL8S
MT.4!,(/CQC/`Y6,``(H"`:#A8?__Z[0AG^6TP9_E&!"=Y0(@C^``()+E#,"/
MX!Q0G>4!`%7C`#"@X00`C.4``)'E"""#Y8PAG^4``(/E`B"/X`P@@^6`(9_E
M`B"/X`0@@^5.``#:!`!!X@S`@^(%`8#@!."QY03@K.4``%'A^___&@,0A>(`
M`*#C4%&?Y0``C>4!`8/G2!&?Y050C^`$(*#A#`"5Y0$0C^!W___K`$!0XB@`
M``HL49_E(&"-X@50C^`,`)7E)?__ZQP!G^4&$*#A``"/X*,``.L``%#C(0``
M"@@QG^4#,(_@#`"3Y0;__^M?___K^""?Y;@PG^4"((_@`S"2YP`@D^4D,)WE
M`B`SX``PH.,C```:!`"@X2C0C>)P@+WH%O__Z\@@G^4"((_@``!0XPP`@N4;
M```*[_[_ZX0PG^4#0)3G``"4Y=_^_^M[5\#EG/__Z@P`E>5H___K`$"@X=+_
M_^H(`)7E``!0XP$```HS"`#KV/__ZG@`G^4&$*#A``"/X'8``.L``%#C"`"%
MY='__PKU___J2?__ZP00H..V___JW?[_ZP$`H.,.___K`.H!``@!``#$Z0$`
M(`$``"@!```4`0``$`$``*#J`0"@Z@$`B#8``'@V```PZ@$`(`D```SJ`0#,
M,P``Y.D!`%3H`0"<Z0$`M#(```"PH.,`X*#C!!"=Y`T@H.$$("WE!``MY1R@
MG^48,(_B`Z"*X``PH.,$,"WE#`"?Y0``FN>-_O_K-___ZQSG`0`D`0``%#"?
MY10@G^4#,(_@`B"3YP``4N,>_R\!W?[_Z@3G`0`<`0``+`"?Y2PPG^4``(_@
M`S"/X```4^$@,)_E`S"/X![_+P$8()_E`C"3YP``4^,>_R\!$_\OX53H`0!0
MZ`$`T.8!``0!```X`)_E.#"?Y0``C^`#,(_@`#!#X*,?H.%#$8'@)#"?Y<$0
ML.$#,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_A$.@!``SH`0"`Y@$`+`$`
M`$PPG^5,()_E`S"/X``PT^4"((_@``!3XQ[_+Q$X,)_E$$`MZ0,PDN<``%/C
M`@``"B@PG^4#`)_G4_[_Z\K__^L<,)_E`2"@XP,PC^``(,/E$("]Z,#G`0!$
MY@$```$``%CG`0"`YP$`T/__ZLPPG^7P1RWI`(!0X@,PC^`K```*O""?Y0(P
MD^<`D)/E``!9XR@```H`4-CE`7"@X0``5>,]`%43`5"@$P!0H`,1```:`$"9
MY0``5.,,```*"6"@X00`H.$%(*#A"!"@X=#^_^L``%#C`@``&@4PU.<]`%/C
M"P``"@1`MN4``%3C\___&@0`H.'PA[WH"%"@X0$P]>4``%/C/0!3$_O__QH(
M4$7@YO__Z@E@1N`!4(7B1F&@X05`A.`$`*#A`&"'Y?"'O>@(0*#A[?__Z@E`
MH.'K___JW.4!`#`!``"0()_ED#"?Y0(@C^`00"WI<-!-X@,PDN<-$*#A`$"@
MX0`PD^5L,(WE`#"@XQS^_^L``%#C``"@$P0``!H0,)WE#SH#X@H*4^,!"5,3
M"@``"D@@G^5`,)_E`B"/X`,PDN<`()/E;#"=Y0(@,^``,*#C!P``&G#0C>(0
M@+WH`A"@XP0`H.%[_O_K$`]OX:`"H.'N___J$?[_ZP3E`0`(`0``M.0!`&`A
MG^5@,9_E`B"/X/!`+>D#,)+G?-!-X@!04.(`,)/E=#"-Y0`PH.,"```*`##5
MY0``4^,*```:,"&?Y2@QG^4"((_@`S"2YP`@D^5T,)WE`B`SX``PH.-!```:
M?-"-XO"`O>@5_O_K`$!0XO'__PH$`*#A8O[_ZP``4.,J```*$S#0Y1-@@.(N
M`%/C`@``&@$PUN4``%/C]/__"A,PT.4N`%/C)0``"@4`H.$8_O_K`'"@X08`
MH.$5_O_K``"'X`(`@.(#_O_KI#"?Y0`@X.,#,(_@`1"@XP1@C>4`4(WE`'"@
MX1G^_^L($(WB!P"@X=?]_^L!`'#C!P"@X0,```H8,)WE#SH#X@$)4^,2```*
MTOW_ZP<`H.&O_?_K!`"@X3?^_^L``%#CU/__&@0`H.%%_O_K!0"@X;/]_^N]
M___J`3#6Y2X`4^/6__\:`C#6Y0``4^/%__\*TO__ZJ?__^OK___JM/W_ZV#D
M`0`(`0``*.0!`"`N``#P0RWI`9"@X0@1G^4(,9_E`=I-X@S03>(!$(_@`S"1
MYP!@H.$!"HWB!`"`X@`PD^4`,(#E`#"@X^``G^4$@(WBW""?Y0``C^`($*#A
ML?W_Z]!PG^4'<(_@`$!0X@<``-H(4(WB`3!$X@/`A>`$(%SE``!2XQ<``!H`
M`%/C%```&J0PG^4#,)?G``"3Y7?]_^L)(*#A!A"@X9O]_^N,()_E=#"?Y0(@
MC^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@,^``,*#C$@``&@':C>(,T(WB\(.]
MZ`-`H.$$(*#A+Q"@XP@`H.'9_?_K``!0X^/__PHT,)_E`S"7YP``D^5;_?_K
M!#"@X0@@H.$&$*#AX?W_Z^'__^IJ_?_KV.(!``@!```\+0``_P\``)SB`0`0
M`0``3.(!`/!'+>D`,-'E$"*?Y3T`4^,,,I_E`B"/X`%`H.$#,)+G`4"!`@C0
M3>(`4*#A!`"@X0`PD^4$,(WE`#"@XXG]_^L-$*#AW(&?Y0B`C^``8*#A!0"@
MX=[^_^L`D%#B0```"H#]_^L``%;A-P``FK@QG^4`<)WE`X"8YP=QH.$`,-7E
M``!3XST`4Q,!,*`3`#"@`P4```H%,*#A`2#SY0``4N,]`%(3^___&@4P0^`"
M`(;B`P"`X`!@F.5;_?_K``!0XP<`AN<5```*`""8Y04`H.$!,-#D!Q"2YP``
M4^,]`%,3`##!Y08```H!(('B`3#0Y`(0H.$]`%/C``!3$P$PPN3Y__\:/3"@
MXP$@H.$`,,'E`3#4Y`$PXN4``%/C^___&@@AG^7X,)_E`B"/X`,PDN<`()/E
M!#"=Y0(@,^``,*#C-0``&@C0C>+PA[WH`9!)X@$PU.0!,.GE``!3X_O__QKN
M___JP#"?Y0.`F.<`<)CE`#"7Y0``4^,D```*!S"@X00@L^4)$*#A``!2XP&0
MB>+Z__\:`Q"!X@$1H.&0,)_E`S"/X``@D^4``%+C#P``&@$@H.,!`*#A`""#
MY1K]_^L`H%#BU?__"@<0H.$)<:#A!R"@X=+\_^L`H(CE`#"@XP"0C>4!D(GB
M"3&*YZ+__^H'`*#A\?S_ZP``4.,`H*#A``"(Y<7__PH)<:#A\O__Z@.0H.$(
M$*#CW___ZMO\_^NHX0$`"`$``'3A`0`P`0``E.`!`)3A`0`P0"WI<$"?Y7`P
MG^4$0(_@`U"4YQ303>(``)7EN/S_ZP``E>6V_/_K5""?Y50PG^54$)_E`B"4
MYP,PC^`!$(_@#""-Y0[]_^L``)7EK/S_ZS@PG^4X()_E.!"?Y0,PC^``P*#C
M`B"/X`$0C^`($(WH&/W_ZQ30C>(P@+WH>-\!`!`!```,`0``]&H``.@I``"D
M+```3!4``-@I```00"WI/$"?Y3PPG^4$0(_@`S"4YPC03>(``)/ED?S_ZR@@
MG^4H,)_E*!"?Y0(@E.<#,(_@`1"/X`0@C>4(T(WB$$"]Z.?\_^K<W@$`$`$`
M``P!``!@:@``5"D``.`@G^5P0"WIW#"?Y0+:3>(8T$WB`B"/X`,PDN<"&HWB
M%!"!X@`PD^4`,('E`#"@X[K\_^NT$)_EM#"?Y0Q`C>(!$(_@`6J-XJ@@G^4#
M,(_@$&"&X@,`C>@!$*#C!`"@X</\_^L$`*#A`2J@XP80H.&/_/_K`$!0XA@`
M`+H!`(3BG?S_ZP!04.(4```*!""@X080H.%?_/_K`#"@XP0PQ>=4()_E0#"?
MY0(@C^`"&HWB`S"2YQ00@>(`()/E`#"1Y0(@,^``,*#C`P``&@4`H.$"VHWB
M&-"-XG"`O>A?_/_K`%"@X^W__^IXW@$`"`$``"PI```4*0```1```.3=`0"^
M___J2"*?Y?!/+>E$,I_E0MU-X@303>("((_@`&"@X30"G^4#,)+G0<V-XA"`
MC>(!0*#A``"/X`@0H.$\P(SB`#"3Y0`PC.4`,*#CU/W_ZR\0H.,`4*#A!@"@
MX7O\_^L``%#C$@``"O`!G^4&$*#A``"/X-7^_^L&`*#AX"&?Y=`QG^4"((_@
M01V-X@,PDN<\$('B`""3Y0`PD>4"(#/@`#"@XVD``!I"W8WB!-"-XO"/O>@$
M`*#A)?S_ZZ01G^4!$(_@D?S_ZP!`4.+E__\*`##4Y9"1G^6`H(WB``!3XPF0
MC^`$<$KB.P``"@``5>,$```*!!"@X04`H.'M^__K``!0XRL```H$`*#A2?S_
MZP$P0.(#,(3@`P!4X0"PH.$`,(0P`!"@,P$`A#(#```Z"```Z@,`4.$`$,/E
M`@``"@$@<^4O`%+C^?__"@0`H.$X_/_K`+"@X08`H.$U_/_K"P"`X`$`@.(!
M"E#CO?__*O@`G^4),*#A``"/X`$JH.,!$*#C00"-Z0!`C>4'`*#A-_S_ZP@0
MH.$'`*#A]?O_ZP``4.,#```:8#`:Y0\Z`^(""5/C%0``"K00G^4``*#C`1"/
MX%'\_^L`0%#BI?__"@`PU.4``%/CP___&@``5>,6```*`##5Y2X`4^,#```*
M@$"?Y0&PH.,$0(_@U?__Z@$PU>4``%/CZO__"O?__^H!$*#C!P"@X3;\_^L`
M`%#CY/__&E``G^4'$*#A``"/X&;^_^L'`*#AQ?O_ZX[__^HX0)_E`;"@XP1`
MC^#!___JPOO_ZW3=`0`(`0``0"@``!`H```(W0$`T"<``+0G```D)P``T"8`
M`'@F``!4)@``*"8``!!`+>DO$*#C`$"@X2'\_^L``%#C`4"`$@0`H.$00+WH
MJOO_ZG0AG^5P0"WI<#&?Y0':3>("((_@"-!-X@$:C>(#,)+G`&!0X@00@>(`
M,)/E`#"!Y0`PH.,O```*`##6Y0``4^,L```*T?O_ZP$@@.(!"E+C`$"@X3@`
M`(H$4(WB!A"@X04`H.&!^__K`3!$X@,PA>`%`%/A!P``F@`0H.,"``#J!0!3
MX0$0P^4"```*`2!3Y"\`4N/Y__\*+Q"@XP4`H.'S^__K``!0XR4```H%`%#A
M`#"@@P`PP(4%`*#A>OO_Z[P@G^6T,)_E`B"/X`$:C>(#,)+G!!"!X@`@D^4`
M,)'E`B`SX``PH.,B```:`=J-X@C0C>)P@+WHB""?Y7PPG^4"((_@`1J-X@,P
MDN<$$('B`""3Y0`PD>4"(#/@`#"@XQ0``!I@`)_E``"/X`':C>((T(WB<$"]
MZ%O[_^H``*#CWO__ZD0@G^4P,)_E`B"/X`$:C>(#,)+G!!"!X@`@D^4`,)'E
M`B`SX``PH.,@`)\%``"/`.S__PI.^__KU-H!``@!```<V@$`Y-D!`*`D``"8
MV0$`6"0``,@DG^7(-)_E`B"/X'!`+>G`9)_E`S"2YPC03>*X5)_E!F"/X`U`
MH.$`,)/E!#"-Y0`PH.,%4(_@!!"@X08`H.''_/_K``!0XPX```J,-)_E``"=
MY0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C
M^___&NO__^I49)_E!F"/X`00H.$&`*#AL?S_ZP``4.,.```*-#2?Y0``G>4#
M,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O_
M_QKK___J`&2?Y09@C^`$$*#A!@"@X9O\_^L``%#C#@``"MPSG^4``)WE`S"5
MYP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:
MZ___ZJQCG^4&8(_@!!"@X08`H.&%_/_K``!0XPX```J$,Y_E``"=Y0,PE><`
M$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO_
M_^I88Y_E!F"/X`00H.$&`*#A;_S_ZP``4.,.```*+#.?Y0``G>4#,)7G`!"3
MY0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O__QKK___J
M!&.?Y09@C^`$$*#A!@"@X5G\_^L``%#C#@``"M0RG^4``)WE`S"5YP`0D^4`
M,8'@!""3Y0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:Z___ZK!B
MG^4&8(_@!!"@X08`H.%#_/_K``!0XPX```I\,I_E``"=Y0,PE><`$)/E`#&!
MX`0@D^4`(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO__^I<8I_E
M!F"/X`00H.$&`*#A+?S_ZP``4.,.```*)#*?Y0``G>4#,)7G`!"3Y0`Q@>`$
M()/E`"&!YP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O__QKK___J"&*?Y09@
MC^`$$*#A!@"@X1?\_^L``%#C#@``"LPQG^4``)WE`S"5YP`0D^4`,8'@!""3
MY0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:Z___ZK1AG^4&8(_@
M!!"@X08`H.$!_/_K``!0XPX```IT,9_E``"=Y0,PE><`$)/E`#&!X`0@D^4`
M(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO__^I@89_E!F"/X`00
MH.$&`*#AZ_O_ZP``4.,.```*'#&?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!
MYP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O__QKK___J#`&?Y000H.$``(_@
MUOO_ZP`04.("```*^`"?Y0``C^#<_/_K\`"?Y000H.$``(_@S?O_ZP`04.("
M```*W`"?Y0``C^#3_/_KU`"?Y000H.$``(_@Q/O_ZP`04.(2```*P`"?Y0``
MC^#*_/_KN""?Y60PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,0```:F!"?
MY9@`G^4!$(_@``"/X`C0C>)P0+WHNOS_ZH0`G^4$$*#A``"/X*O[_^L`$%#B
MZ?__"G``G^4``(_@L?S_Z^7__^H3^O_K1-D!``@!``!`)```&-D!`#`!``#@
M(P``D",``$0C``#T(@``K"(``/`A```((@``O"$``'`A``"<(```R"```)P@
M``"X(```N"```+0@``#8'P``X-0!`)`@``#T'P``8"```.0?``"<,)_EG!"?
MY9P@G^4#,(_@!.`MY0$0C^```)/E`B"1YPS03>(!`'#C`""2Y00@C>4`(*#C
M"@``"G`@G^5H,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C$```&@S0C>($
M\)WD2`"?Y0T0H.$``(_@;?O_ZP``4.,$```*``#0Y3``4.,``%`3`0"@$P``
MH`,@,)_E`S"/X```@^7E___JT/G_ZT35`0``U`$`"`$``-33`0``'P``O-0!
M`!!`+>FJ^?_KH_G_ZP``4.,``)`5$("]Z#PAG^7P0"WI.#&?Y3AAG^4"((_@
M'-!-X@,PDN<&8(_@`%"@X1`0C>(&`*#A`#"3Y10PC>4`,*#C1OO_ZP!`4.("
M```*`##4Y0``4^,.```:^""?Y>PPG^4"((_@`S"2YP`@D^44,)WE`B`SX``P
MH.,R```:V`"?Y040H.$``(_@'-"-XO!`O>@]_/_J!1"@X6_Y_^L``%#C"@``
M"K0@G^6@,)_E`B"/X`,PDN<`()/E%#"=Y0(@,^``,*#C'P``&AS0C>+P@+WH
M!0"@X<;Y_^L`<*#A!`"@X</Y_^L``(?@`@"`XK'Y_^ML()_E;#"?Y0(@C^`#
M,(_@`1"@XPA`C>4$((WE`%"-Y0`@X.,`0*#AQ/G_ZT@@G^4H,)_E`B"/X`,P
MDN<`()/E%#"=Y0(@,^``,*#C!!"@`08`H`'/__\*<_G_ZS#3`0`(`0``_!X`
M`.C2`0"<'@``G-(!`%0=``!4'0``)-(!`'`7G^7P3RWI;">?Y0+93>+\T$WB
M`1"/X&`WG^4"()'G`'"@X0()C>(#,(_@`""2Y?0@@.4`(*#C]`"`X@<`D^GX
M8(WB=*!&XA#@@^(HD(/B!P"*Z`\`ONA<P$;B#P"LZ`,`GNAH0$;B`P",Z`<`
MF>@'`(3H"`>?Y>!01N(%$*#A``"/X-GZ_^OXAI_E"("/X`!`4.("```*`##4
MY0``4^,+`0`:(OG_ZQOY_^L``%#CZ@``"@"@D.4``%KCYP``"@H`H.%N^?_K
M@`"@X0$`@.)<^?_K`##:Y0``4^,`0*#A`)"@X0L```J<MI_E"["/X`0`H.$`
M,(WE`"#@XPLPH.$!$*#C;?G_ZP$P^N4"0(3B``!3X_7__QIP!I_E7*!&X@``
MC^`"``#J!`"ZY0``4.,-```*!1"@X:SZ_^L`0%#B^/__"@`PU.4``%/C]?__
M"MWZ_^L``%#C\O__"@0`H.$.^?_K`$!0X@X``!ITH$;B!$":Y```5.,*```*
M`##4Y0``4^.S```*!`"@X<[Z_^L``%#C]?__"@0`H.'_^/_K`$!0XO'__PH$
M`*#A-/G_ZP"@H.$)`*#A,?G_ZP"@BN`!JXKB!*"*X@H`H.$=^?_KO#6?Y0`@
MX.,#,(_@"#"-Y;`UG^4!$*#C`S"/X`0PC>6D-9_E#)"-Y0,PC^``0(WE`+"@
MX2WY_^L'':#C"P"@X3/Y_^L!`'#C`P``&B3Y_^L`$)#E$0!1XYX``!H%$*#A
M"P"@X<WX_^L`D%#B&```"E@EG^4`,)?E`A"8YU`EG^4``)'E`B"/X`$0H.,`
ML(WE+OG_ZP"`H.,X)9_E"#6?Y0(@C^`"&8WB`S"2Y_00@>(`()/E`#"1Y0(@
M,^``,*#C-P$`&@@`H.$"V8WB_-"-XO"/O>C0,!;E#SH#X@$)4^/B__\:R$`6
MY9WX_^L``%3AWO__&M`P%N6#.Z#AHSN@X0<-4^/9__\:"@"@X=GX_^L%$*#A
M`("@X;P$G^4``(_@/OK_ZP`04.*.```*``"7Y5+\_^L`H%#BB@``"@H`H.';
M^/_K`P!0XP!`H.$,``":B!2?Y00`0.(``(K@`1"/X'/X_^L``%#C!0``&@0`
M5./8```*!$"*X`4P5.4O`%/CU```"EA$G^4$0(_@`#"4Y0$`<^/!```*``!3
MXW,```I`%)_E0`2?Y0$0C^```(_@)?O_Z[CX_^LP-)_E,'2?Y0,PC^`,,(WE
M*#2?Y2ADG^4#,(_@!#"-Y2`TG^4@5)_E`S"/X``@X.,!$*#C`+"-Y0=PC^`&
M8(_@!5"/X`@`C>4(`*#AN?C_ZP\``.JT^/_K`#"0Y1$`4^,1```:GOC_ZP&0
MB>(',*#A!""@X0$0H.,08(WE#)"-Y0"PC>4`P*#A(!"-Z0@`H.&H^/_K!QV@
MXP@`H.&N^/_K`0!PXP!`H.'I__\*"P"@X4/X_^N4`Y_E"!"@X0``C^#S^O_K
M"`"@X9#^_^N#___J`T"@X5'__^IH0$;B!`"4Y```4.,I```*!1"@X=WY_^L`
M,%#B^/__"@`PT^4``%/C]?__"D/X_^L`H%#B\O__"GGX_^N``*#A`0"`X@G_
M_^KP(I_E`#"7Y0(`F.<@(Y_E``"0Y0(@C^`$$(WE`+"-Y0$0H..3^/_K8___
MZF_^_^L`(Y_EF#*?Y0(@C^`"&8WB`S"2Y_00@>(`()/E`#"1Y0(@,^``,*#C
MFP``&@0`H.$"V8WB_-"-XO!/O>@A^/_J#0"@XTGX_^N\HI_E4S"@XPJ@C^``
M0*#A`)"@X>O^_^H`H)?E<O__Z@H`H.$`$*#C._C_ZP!`4.*&__\*`E"@XP`P
MX.,1(.#C!'!&X@!0C>4J^/_K!B"@XP<0H.$$`*#AZO?_ZP0P5N4``%/C`@``
M&@,P5N5#`%/C4P``"@`PH.,`(*#C`#"-Y00`H.$`,*#C&OC_Z\$$`.L`4*#A
M`@``Z@<0H.$%`*#AWP0`ZP(IH.,'$*#A!`"@X=3W_^L`(%#B]O__R@0`H.%$
M0$;B<?C_ZP40H.$$`*#A&04`Z^R1G^4P<$;B"9"/X`=0H.$!$-3D!0"@X0`0
MC>4),*#A`"#@XP$0H.,G^/_K!`!7X0)0A>+U__\:N#&?Y0`@H.,#,(_@!#"-
MY0APC>4`L(WE""!&Y:`AG^6@,9_E`B"/X`P@C>4#,(_@`"#@XP$0H.,(`*#A
M%/C_ZW#__^J``9_E!1"@X0``C^!;^?_K``!0XP``A`6L__\*`##0Y0``4^,P
M`%,3`3"@$P`PH`,`,(3E+___Z@1`E^4``%3C)___"@0`H.'Q]__K`P!0XR/_
M_YHP$9_E!`!`X@``A.`!$(_@BO?_ZP``4.,$H*`!&___Z@(P5N5!`%/CJ/__
M&@$P5N5#`%/CI?__&@`PUN5(`%/CHO__&@$PUN5%`%/CG___&@`PX.,Y(.#C
M!`"@X0!0C>6[]__K!Q"@X2D@H.,$`*#A>_?_Z\`PG^7`$)_E`S"/X`PPC>6X
M,)_E`1"/X`00C>4#,(_@`"#@XP$0H.,(`*#A"'"-Y0"PC>73]__K+___ZHSW
M_^O$T0$`"`$``.S2`0!`'```3-$!`-P<``!<'```!!P````;``#8&P``&`$`
M`,P;``!HSP$`B!L``%`;``"\SP$`-!H``+09``#$&P``[!H``$@9``"0&P``
M[!H``"`9``!\&```*!D``/C,`0"8&```S!<``+06```$&0``-!@``+@6``"T
M%P``%!@``)P5```X%P``=`*?Y702G^4``(_@\$`MZ0$0D.=H,I_E#-!-XF0B
MG^4#,(_@`!"1Y000C>4`$*#C`D"3YPU@H.$``)3E0O?_ZP!0H.$``)3E/_?_
MZV@@U>4&$*#A`#"@X2P"G^5I(,/E``"/X-[X_^L``%#C`@``"@`PT.4Q`%/C
M8P``"O_[_^L``)3E,/?_ZP`2G^4#,*#C`2"@XP$0C^!J]__K`%!0X@L```H`
M`)3E)_?_ZQ`PE>7<(9_E`!"3Y0(@C^!)]__K$#"5Y0`PD^4(,)/E`043XUH`
M`!H``)3E&_?_Z[01G^4#,*#C`2"@XP$0C^!5]__K`%!0X@L```J<`9_E!A"@
MX0``C^"V^/_K`'!0X@``E.5!```*#/?_ZQ`PE>4'(*#A`!"3Y2_W_^L``)3E
M!O?_ZP!0H.$``)3E`_?_ZUP1G^4!(*#C`1"/X%/W_^M0(9_E`B"/X``0H.$%
M`*#A(??_ZP``E.7X]O_K`""@XP80H.$P49_E!5"/X``PH.$H`9_E:2##Y0``
MC^"5^/_K``!0XP!`H.$(`(7E$@``"@<=H.,$`*#A2_?_ZP$@@.(1`%#C`0!2
M$P`PH.$G``"*[""?Y;@PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,=```:
M#-"-XO"`O>@$`)7E@/W_ZP``4.,`0*#A"`"%Y>;__QJL`)_E``"/X"SW_^L!
M,-#E``!3XYG__PJ7___JRO;_ZY`PG^40()7E`S"/X`0PD^4``)+E`!"3Y2?Y
M_^NY___J``"4Y<#V_^L0,)7E`!"3Y2GW_^N>___JT/;_ZU@@G^58`)_E`B"/
MX`0@DN4``(_@`!"2Y00@H.$0]__KQ,D!``@!``"LR0$`$`$``*@4```@%@``
M`!8``-@5``#`$P``@!4``(P5``#0R0$`,!,```C(`0#@%```',D!`.#(`0"<
M%```/"&?Y3PQG^4"((_@\$`MZ0,PDN<,T$WB`#"3Y00PC>4`,*#C`%"@X?WZ
M_^LO$*#C%'&?Y0=PC^``0*#A%??_ZP``4.,!0(`2!`"@X9_V_^L`,)?E`$!5
MX@%`H!,!`'/C`&"@X28```H``%/C`$"@`P%`!!(``%3C"@``&LP@G^7`,)_E
M`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C)P``&@S0C>+P@+WH`##5Y0``4^/Q
M__\*F!"?Y00@H.,!$(_@!@"@X?_V_^L``%#CZO__&H`@G^5L,)_E`B"/X`,P
MDN<`()/E!#"=Y0(@,^``,*#C$@``&@4`H.$,T(WB\$"]Z&;X_^I0`)_E#1"@
MX0``C^`"^/_K``!0XP``AP76__\*`##0Y0``4^,P`%,3`3"@$P`PH`,#0`3@
M`#"'Y<S__^IE]O_K`,<!``@!```0R`$`A,8!`%`2```PQ@$`5!$```````#P
M3RWI7.R?Y5P\G^4.X(_@I]]-X@,PGN<0((WB`!"@X4#`@.*`4(#B`#"3Y90R
MC>4`,*#C`@"@X0!`H.,$8!SE"'`<Y28TH.%GZ"?@_SP#XB8\@^$NY*#A!H2@
MX08\@^'_[,[C_V@(X@C`C.)GY"[@!C"#X04`7.$`X(#E!$"`Y0@P@.4,0(#E
M$`"`XNK__QJ"/X+B!#"-Y8@PG>48X(WB'*"=Y0@0C>5X@)WE?""=Y1BPG>6`
M<)WEA&"=Y8S`G>404)WE%$"=Y0X`H.$#$*#A#."-Y0"@C>4!``#J";"@X0`P
MC>4!,*#A/."0Y3@0D.4(D+#E`*"@XPD0(>`($"'@!X"@X0-PH.$$,)#E!1`A
MX`/@+N`"X"[@!.`NX`8@H.$,8*#AH<^@X8[`C.$!$)'@#!"!X03`G>4`0)WE
M``!<X0M0H.$*P*#A=*"`Y7`0@.7A__\:"!"=Y0S@G>4`@)'E"#N?Y0$(D>D(
M(![E($"1Y:AMH.$0<)'E&)"1Y0,@DN"`8H;A!""2X(ABAN$,P)'E`F"6X`D@
M)^`K4:#A"R`"X`D@(N`,7X7A`F"6X`M?A>$8()WE*,&@X0#/C.$%`"?@`R"2
MX`@``.`)()+@!P`@X`C/C.$``)+@""">Y0Q`)>`#()+@!D`$X`5`).`'()+@
MY@V`X`0@DN#@38+@$"">Y0,@DN`%()+@9E$LX`!0!>`,4"7@!2"2X!A0GN5@
M`:#A`U"5X`S`E>!F42#@!%`%X&91)>#D+8+@!<"<X.)=C.`@P)[E`\"<X&;!
MC.!D82#@`F`&X`!@)N`&P)S@*&">Y6(AH.$#8);@``"6X&1A(N`%8`;@9&$F
MX.7-C.`&`)#@[&V`X#``GN4#`)#@9`&`X&5!(N`,0`3@`D`DX`0`D.`X0)[E
M;,&@X0-`E.`"()3@94$LX`9`!.!E023@Y@V`X`0@DN#@38+@0"">Y0,@DN!E
M(8+@9E$LX`!0!>`,4"7@!2"2X$A0GN5@`:#A`U"5X`S`E>!F42#@!%`%X&91
M)>#D+8+@!<"<X.)=C.!0P)[E`\"<X&;!C.!D82#@`F`&X`!@)N`&P)S@6&">
MY6(AH.$#8);@``"6X&1A(N`%8`;@9&$FX.7-C.`&`)#@[&V`X&``GN4#`)#@
M9`&`X&5!(N`,0`3@`D`DX`0`D.!H0)[E;,&@X0-`E.`"()3@94$LX`9`!.!E
M023@Y@V`X`0@DN#@38+@<"">Y0,@DN!E(8+@9E$LX`!0!>`,4"7@!2"2X'A0
MGN5@`:#A`U"5X`S`E>!F42#@!%`%X&91)>#D+8+@!<"<X.)=C."`P)[E`\"<
MX&;!C.!D82#@`F`&X`!@)N`&P)S@Y6V,X(C`GN5B(:#A`\"<X```G.!DP2+@
M!<`,X&3!+.`,`)#@YLV`X)``GN4#,)#@90$BX`8``.`"`"#@9#&#X``PD^#L
MK8/@F`">Y2PXG^5F8:#A`P"0X*!`GN4"()#@90$FX`P`(.``()+@`P"4X&4!
M@.#J38+@J%">Y6PA)N`*("+@`@"0X&HAH.$#4)7@L*">Y090E>!L82+@!&`F
MX.0-@.`&4)7@`V":X&QAAN"XH)[EX,V%X&11(N``4"7@!6"6X&`!H.$#4)K@
M`E"5X,"@GN7L+8;@9&$@X`Q@)N`&4)7@`V":X&1AAN#(H)[E;$$@X`)`).#B
M787@!&"6X&(AH.$#0)K@``"4X-"@GN5L02+@!4`DX`1`D.`#`)K@Y6V&X-B@
MGN5L`8#@9<$BX`;`+.#F383@#`"0X&9AH.$#P)K@`B"<X."@GN5EP2;@!,`L
MX`S`DN`#()K@Y`V`X.B@GN5E(8+@9%$FX`!0)>#@S8S@!2"2X&`!H.$#4)K@
M!E"5X/B@GN7P8)[E9.$@X`S@+N#L+8+@#N"5X.)=CN`#8);@;.$@X&1!AN`"
MX"[@#N"4X&(AH.$#0)K@`$"4X!AAG>5L`2+@!0`@X.7MCN```)3@`V"6X.Y-
M@.!LP8;@90$BX"!AG>4.`"#@``"<X&[AH.$#8);@`B"6X&7!+N`H89WE!,`L
MX.0-@.`,P)+@`R"6X&4A@N`P89WEX%V,X&3!+N``P"S@#,"2X&`!H.$#8);@
MY2V,X`[@EN!DP2#@.&&=Y07`+.`,P)[@`^"6X&3ACN!`89WE94$@X`)`).#B
MS8S@!.">X&(AH.$#8);@``"6X&5!(N!(89WE#$`DX.SMCN!0H9WE!$"0X`,`
MEN#L-9_E;&$BX&4!@.`.8";@;E&@X>Y-A.`&8)#@;.&%X0,`FN`"`)#@6*&=
MY>0MAN`$X`[@;&$%X`;@CN$.X)#@`Z":X&0!A>%D807@;,&*X`(``.!@H9WE
M!@"`X>+MCN`,`)#@8B&@X0/`FN`%P)S@9%&"X61A`N!HH9WE#E`%X`90A>'N
M#8#@#%"5X`.@FN!NP8+A;F$"X&1!BN``P`S@<*&=Y0;`C.'@787@!$"<X&`!
MH.$#P)K@`L"<X.4MA.!N08#A;F$`X'BAG>4%0`3@!D"$X0Q`E.`#H)K@9<&`
MX65A`.!NX8K@`L`,X("AG>4&P(SAXDV$X`[@G.!B(:#A`\":X`#`G.#D#8[@
M9>&"X65A`N"(H9WE!.`.X`;@CN$,X)[@`Z":X&3!@N%D80+@95&*X`#`#."0
MH9WE!L",X>#MCN`%4)S@8`&@X0/`FN`"P)S@[BV%X&11@.%D80#@F*&=Y0Y0
M!>`&4(7A#%"5X`.@FN!NP8#A;F$`X&1!BN`"P`S@H*&=Y0;`C.'B787@!$"<
MX&(AH.$#P)K@`,"<X.4-A.!N08+A;F$"X*BAG>4%0`3@!D"$X0Q`E.`#H)K@
M9<&"X65A`N!NX8K@`,`,X+"AG>4&P(SAX$V$X`[@G.!@`:#A`\":X`+`G.#D
M+8[@9>&`X65A`."XH9WE!.`.X`;@CN$,X)[@`Z":X&3!@.%D80#@95&*X`+`
M#.#`H9WE!L",X>+MCN`%4)S@8B&@X0/`FN``P)S@[@V%X&11@N'(H9WE9&$"
MX`Y0!>`&4(7A#%"5X`.@FN!NP8+A;F$"X&1!BN``P`S@T*&=Y0;`C.'@787@
M!$"<X&`!H.$#P)K@`&"@XP+`G.#E+83@;D&`X05`!.`$8('E#&"!Y11@@>4<
M8('E;F$`X-BAG>4&0(3A#$"4X&7!@.$#H)K@96$`X`+`#.!NX8K@!L",X>"A
MG>7B383@#L"<X&(AH.'D[8S@`Z":X&7!@N%E80+@``":X`3`#.#HH9WE!L",
MX0#`G.`#H)K@9`&"X>@RG^5D80+@95&*X`X``.#PH9WE!@"`X>[-C.`%`)#@
M;N&@X0-0FN`"4)7@^&&=Y60A+N`,("+@[`V`X`(@E>`#8);@X%V"X&1!AN!L
M(2[@`&*=Y0`@(N`"()3@8`&@X0-`EN`.0)3@"&*=Y6SA(.`%X"[@#N"4X`-`
MEN#E+8+@$&*=Y6Q!A.!EP2#@`L`LX.+MCN`,P)3@8B&@X0-`EN``0)3@&&*=
MY64!(N`.`"#@[LV,X```E.`#0);@94&$X"!BG>7L78#@;@$BX`P`(.```)3@
M;,&@X0-`EN`"0)3@*&*=Y6XA+.`%("+@Y0V`X`(@E.`#8);@X$V"X&[AAN!E
M(2S@,&*=Y0`@(N`"()[@8`&@X0/@EN`,X)[@.&*=Y67!(.`$P"S@Y"V"X`S`
MGN`#X);@9>&.X$!BG>7B78S@9,$@X`+`+.`,P)[@8B&@X0/@EN``X)[@2&*=
MY60!(N`%`"#@Y<V,X```GN`#X);@9.&.X%!BG>7L38#@90$BX`P`(.```)[@
M;,&@X0/@EN`"X)[@6&*=Y64A+.`$("+@Y`V`X`(@GN`#X);@9>&.X&!BG>7@
M78+@9"$LX``@(N`"()[@8`&@X0/@EN`,X)[@:&*=Y63!(.`%P"S@Y2V"X`S`
MGN`#X);@9.&.X'!BG>7B38S@9<$@X`+`+.`,P)[@8B&@X0/@EN``X)[@>&*=
MY64!(N`$`"#@``">X`/@EN#DS8S@9>&.X&1A(N"`4IWE#&`FX.P-@.`&X)[@
M;,&@X0-0E>`"()7@9&$LX(A2G>4`8";@!B"2X`,PE>#@[8[@8)&)X`@PD^!@
M`2S@#@`@X&0Q@^``,)/@[BV"X.(]@^!N<8?@"R"2X"``D>48D('E$'"!Y0`P
M@>4((('E4""?Y3@PG^4"((_@`,"<X`!@H.,@P('E)&"!Y0,PDN<`()/EE#*=
MY0(@,^``,*#C`0``&J??C>+PC[WH0_/_ZYC%`0`(`0``F7F"6J'KV6[<O!N/
MUL%BRG2Y`0!P0"WI@`"@XV#S_^M04(_BT$#%X0`@H./P0,#A2%"/XM!`Q>%X
M((#E^$#`X4!0C^+00,7A\$'`X3Q0C^+00,7A^$'`X3A0C^+00,7A\$+`X0!`
MH.,`4*#C^$+`X?!#P.%P@+WH`2-%9P````")J\WO`````/[<NI@`````=E0R
M$`````#PX=+#`````/!'+>DH,)#E`F"@X8;!@^`L()#E`P!<X0`PH.,"(-/@
M`%"@X3`@D.4!0*#A-!"0Y<8/H.$!```J`2"2X@`0H>(L,(7EICZ@X8`Q@^$"
M,)/@H!ZAX'@`E>4X@(7B``!0XRC`A>4P,(7E-!"%Y18``!H_`%;C)0``VD!@
M1N(FDZ#A`7")X@=SA.`$$*#A0""@XP@`H.'A\O_K0$"$X@4`H.&2_/_K!P!4
MX?;__QH)G6G@"6.&X`8@H.$'$*#A"`"@X=;R_^MX8(7E\(>]Z$!P8.(&`%?A
M!G"@H0``B.`'(*#A!!"@X<WR_^MX,)7E`S"'X$``4^-X,(7E\(>]&`4`H.$'
M8$;@!T"$X'C\_^O7___J!'"@X>;__^KP02WI*#"1Y0%`H.%C*"/@,!"1Y2(D
MH.'_+,+C8W0BX&$H(>"C,:#A(B2@X3\P`^+_+,+C860BX`$@@^(X@(3B?Q#@
MXS@`4N,`4*#A`Q#(YP(`B.`\``#:0"!BX@`0H.,+\__K!`"@X5K\_^L(`*#A
M.""@XP`0H.,%\__K!`"@X7!@A.5T<(3E4OS_ZP,PU.4`,,7ELC#4X0$PQ>4`
M,)3E!`"@X2,TH.$",,7E`#"4Y0,PQ>4+,-3E!##%Y;HPU.$%,,7E"#"4Y2,T
MH.$&,,7E"#"4Y0<PQ>43,-3E"##%Y;(QU.$),,7E$#"4Y2,TH.$*,,7E$#"4
MY0LPQ>4;,-3E###%Y;HQU.$-,,7E&#"4Y2,TH.$.,,7E&#"4Y0\PQ>4C,-3E
M$##%Y;(RU.$1,,7E(#"4Y2,TH.$2,,7E(#"4Y1,PQ>7P0;WH:/+_ZC@@8N(`
M$*#CSO+_Z\?__^H(,)_E`S"/X``PD^5[\O_J5+<!``A`+>D(@+WH`0`"`#T`
M``!`````"P```$`````0````0````"8```!`````-0```$`````#````0```
M``8```!`````%````$`````.````0`````T```!`````)0```$`````2````
M0````"@```!``````@```$`````8````0`````D```!`````"@```$``````
M`````````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E
M:2\E<P!E>&4`+@```%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````
M)7,E<R5S```O````4$523#5,24(`````4$523$Q)0@!015),-4]05`````!0
M15),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`
M``!005)?1$5"54<```!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'````
M`%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`````,0```$Q$7TQ)0E)!4EE?4$%42`!3
M65-414T``"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0
M051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E
M;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````&````'!E<FP`````,```
M`%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4V````56YA8FQE('1O(&-R
M96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M```M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)4@!435``+W1M
M<`````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B
M?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA
M9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ
M92P@)$-!0TA%7VUA<FME<BP@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*
M)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@
M/2`T.R`@(",@<&%C:R@B3B(I"B1C86-H95]M87)K97(@/2`B7#!#04-(12([
M"B1C86-H95]N86UE7W-I>F4@/2`T,#L*?0IS=6(@9FEN9%]P87)?;6%G:6,*
M>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*
M;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`D<VEZ92`M
M("1S:7IE("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@
M;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS
M965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE
M("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B
M=68L("1005)?34%'24,I*2`^/2`P*2!["B1P;W,@*ST@)&D["G)E='5R;B`D
M<&]S.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY
M("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]
M("1T;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI
M;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;
M(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E
M("1T;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL
M96YA;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H
M<7%;4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A
M;G5P.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!
M4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE
M=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?
M1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>
M35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O
M7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM
M("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P*
M*3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R
M;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@
M)&1A=&%?<&]S*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S
M=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@
M>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[
M("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M
M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC
M*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F
M:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N
M86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A
M="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,
M15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I
M.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2`D;V9F<V5T+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*;7D@)7)E<75I
M<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@
M97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U
M=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_
M.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT
M*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE
M.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A;F0@9&5F
M:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?
M87,H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T
M=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B
M0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*
M)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5]
M(#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN
M9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*=6YL97-S("@D8G5F(&5Q(")02UPP,#-<,#`T
M(BD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@
M:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@
M;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO
M9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5]
M.R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M
M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I
M;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB
M7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@
M('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%2
M1U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!
M4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A
M<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*
M)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S
M=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q
M(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD
M8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L
M92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*
M?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O
M<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS
M:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!
M4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D
M14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H
M:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$
M:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP
M+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E
M861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D
M;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-
M151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]
M?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG
M.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A
M=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B
M.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P
M87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S
M7#`P-"(["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\
M($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*
M,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D
M(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E
M<CL*:68@*&1E9FEN960@)&1A=&%?<&]S*2!["G)E860@7T9(+"`D;&]A9&5R
M+"`D9&%T85]P;W,["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D
M97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO
M861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L
M;V%D97(L("0P*3L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PIM>2`D<&%R
M7V-L96%N(#T@(CTQ(CL*;7D@)'!A<W-?<&%R7V-L96%N(#T@=6,@(E]?<&%S
M<U]P87)?8VQE86Y?7R(["B1L;V%D97(@/7X@<WLH/SP])'MP87-S7W!A<E]C
M;&5A;GTI*"`K*7T*>R1P87)?8VQE86X@+B`H(B`B('@@*&QE;F=T:"@D,2D@
M+2!L96YG=&@H)'!A<E]C;&5A;BDI*7UE9SL*?0HD9F@M/G!R:6YT*"1L;V%D
M97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z
M("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I
M<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R
M97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP
M<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H
M($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E
M<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L
M:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME
M>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@
M*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y
M?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*
M9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I
M<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL
M87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2![
M"FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N
M86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@
M>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]
M"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET
M=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]
M?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG
M($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D
M9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E
M;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968[
M"F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@
M<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T
M:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\
M96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE
M*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M
M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M
M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H
M*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T
M96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*)&-A
M8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE
M7W-I>F4["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*
M;W!E;B!M>2`D=&@L("(\.G)A=R(L("1O=70["B1C='@M/F%D9&9I;&4H)'1H
M*3L*8VQO<V4@)'1H.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*
M?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L
M96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`D8V%C:&5?;6%R
M:V5R.PIM>2`D;V9F<V5T(#T@)&9H+3YT96QL("L@;&5N9W1H*"1C86-H95]N
M86UE*2`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M
M92P*<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*0HF)B`D9F@M/F-L
M;W-E"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B
M.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH
M*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@
M7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@
M>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@
M)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[
M4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@
M)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T
M<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y
M(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%
M>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI
M.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A
M8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U
M+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S
M<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N
M;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=
M(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;
M("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.
M04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#
M<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A
M<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"
M87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@
M1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H
M+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q
M=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E
M<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W
M87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z
M.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U
M:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!8
M4TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*
M<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q
M=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I
M<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V
M86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE
M=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@
M07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ
M2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@
M<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X
M('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?
M=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@
M)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@
M5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S
M(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@
M)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U
M:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ
M3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64[
M"GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I
M9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.
M5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S
M>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%2
M7T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO
M<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG
M="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`]
M(&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I
M8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@D8V%C:&5?;6%R
M:V5R*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@D8V%C
M:&5?;6%R:V5R*3L*:68@*"1B=68@97$@)&-A8VAE7VUA<FME<BD@>PIS965K
M("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H
M*"1C86-H95]M87)K97(I"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D
M9F@L("1B=68L("1C86-H95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*
M)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II
M9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.
M5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U]
M)&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]4
M14U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*
M<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]
M($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S
M("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD
M)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F
M("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D
M92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA
M;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N
M("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D
M("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^
M("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P
M.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.
M5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]
M"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@
M)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D
M<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G
M;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR
M971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T
M:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[
M4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^
M(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O
M9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II
M9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I
M>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P
M*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM
M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D
M*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET
M7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*
M<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]
M"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'
M3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]
M("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,
M3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.
M5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@````!P97)L>'-I+F,````]````
M0`````L```!`````$````$`````F````0````#4```!``````P```$`````&
M````0````!0```!`````#@```$`````-````0````"4```!`````$@```$``
M```H````0`````(```!`````&````$`````)````0`````H```!`````````
M``````!DC/]_`0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````V!@``'`8```!````%0,```$````E`P``
M`0```"\#```,````N!$```T```"X2```&0```+S]`0`;````!````!H```#`
M_0$`'`````0```#U_O]OK`$```4````D"0``!@```)0"```*````IP0```L`
M```0````%0`````````#````S/X!``(```#H`0``%````!$````7````T`\`
M`!$`````#P``$@```-`````3````"````!X````(````^___;P$```C^__]O
MH`X``/___V\"````\/__;\P-``#Z__]O#@``````````````````````````
M``````````````````````````````#$_0$```````````#$$0``Q!$``,01
M``#$$0``Q!$``,01``#$$0``Q!$``,01``#$$0``Q!$``,01``#$$0``Q!$`
M`,01``#$$0``Q!$``,01``#$$0``Q!$``,01``#$$0``Q!$``,01``#$$0``
MQ!$``,01``#$$0``Q!$``,01``#$$0``Q!$``,01``#$$0``Q!$``,01``#$
M$0``Q!$``,01``#$$0``Q!$``,01``#$$0``Q!$``,01``#$$0``Q!$``,01
M``#$$0``Q!$``,01``#$$0``Q!$``,01``#$$0``Q!$``,01``#$$0``Q!$`
M`,01``#$$0``````````````````````````````````````````````````
MN!0````````````````````````$``(`_____W1,``"P20```````'!*``!T
M2@``:$P``+A)``!P3````````%1,``!<3````````'Q,``!'0T,Z("A$96)I
M86X@,3(N,BXP+3$I(#$R+C(N,`!!*@```&%E86)I``$@````!35410`&!`@!
M"0$2!!,!%`$5`1<#&`$9`1H"`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N
M=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96PN9'EN`"YR
M96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+D%232YE>&ED>``N
M96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`+F=O
M=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````
M```````````````````````````````````````````````+`````0````(`
M``!4`0``5`$``!,```````````````$`````````$P````<````"````:`$`
M`&@!```D```````````````$`````````"8````'`````@```(P!``",`0``
M(```````````````!``````````T````]O__;P(```"L`0``K`$``.@````%
M``````````0````$````/@````L````"````E`(``)0"``"0!@``!@````,`
M```$````$````$8````#`````@```"0)```D"0``IP0``````````````0``
M``````!.````____;P(```#,#0``S`T``-(````%``````````(````"````
M6P```/[__V\"````H`X``*`.``!@````!@````(````$`````````&H````)
M`````@`````/````#P``T`````4`````````!`````@```!S````"0```$(`
M``#0#P``T`\``.@!```%````%0````0````(````?`````$````&````N!$`
M`+@1```,```````````````$`````````'<````!````!@```,01``#$$0``
M\`(`````````````!`````0```""`````0````8```"X%```N!0````T````
M``````````@`````````B`````$````&````N$@``+A(```(````````````
M```$`````````(X````!`````@```,!(``#`2```4$(`````````````!```
M``````"6`````0``<((````0BP``$(L```@````-``````````0`````````
MH0````$````"````&(L``!B+```$```````````````$`````````*L````.
M`````P```+S]`0"\_0``!```````````````!`````0```"W````#P````,`
M``#`_0$`P/T```0```````````````0````$````PP````8````#````Q/T!
M`,3]```(`0``!@`````````$````"````,P````!`````P```,S^`0#,_@``
M-`$`````````````!`````0```#1`````0````,```````(````!`$``````
M``````````0`````````UP````@````#````0``"`$```0`4````````````
M```$`````````-P````!````,`````````!```$`'@```````````````0``
M``$```#E`````P``<```````````7@`!`"L```````````````$`````````
H`0````,``````````````(D``0#U```````````````!````````````
